--[[	file meta info
	@file 		DeathKnight.lua
	@brief		Tables of spell IDs for class
--]]

--[[
	@brief		Accessing the addons private table

	@var 	_		addonName, thrown away
	@var	wt		Global addonTable
--]]
local _, wt = ...

--[[
	@brief		Check if the data should be loaded or not
	@return		If not "DEATHKNIGHT", then return with nothing
--]]
if (wt.currentClass ~= "DEATHKNIGHT") then
	return
end

--[[
	@brief		Table for trainable spells for each level

	@table		[n]		Table containing spells available at level n

				@var		id					Spell id
				@var		cost				Cost in copper
				@table		requiredIds			Table containing prerequisite spell IDs
				@var		requiredTalentId	Spell ID of prerequisite talent
				@var		faction				"Alliance" or "Horde" for faction specific spells
--]]
wt.SpellsByLevel = {
	[56] =	{
				{id = 49998, cost =   5600},													-- Death Strike (rank 1)
				{id = 50842, cost =   5600},													-- Pestilence
				{id = 46584, cost =   5600},													-- Raise Dead
			},
	[57] =	{
				{id = 48263, cost =   5700},													-- Frost Presence
				{id = 47528, cost =   5700},													-- Mind Freeze
			},
	[58] =	{
				{id = 48721, cost =   5800},													-- Blood Boil (rank 1)
				{id = 45524, cost =   5800},													-- Chains of Ice
			},
	[59] =	{
				{id = 49926, cost =   5900, requiredIds = {45902}},								-- Blood Strike (rank 2)
				{id = 55258, cost =   5900, requiredIds = {55050}, requiredTalentId = 55050},	-- Heart Strike (rank 1)
				{id = 47476, cost =   5900},													-- Strangulate
			},
	[60] =	{
				{id = 51325, cost =    300, requiredIds = {49158}},								-- Corpse Explosion (rank 2)
				{id = 43265, cost =   6000},													-- Death and Decay (rank 1)
				{id = 51416, cost =   6200, requiredIds = {49143}, requiredTalentId = 49143},	-- Frost Strike (rank 2)
				{id = 49917, cost =   5800, requiredIds = {45462}},								-- Plague Strike (rank 2)
			},
	[61] =	{
				{id = 49896, cost =  61000, requiredIds = {45477}},								-- Icy Touch (rank 2)
				{id = 49020, cost =  61000},													-- Obliterate (rank 1)
				{id =  3714, cost =  64000},													-- Path of Frost
			},
	[62] =	{
				{id = 49892, cost =  59000, requiredIds = {47541}},								-- Death Coil (rank 2)
				{id = 48792, cost =  62000},													-- Icebound Fortitude
			},
	[63] =	{
				{id = 49999, cost =  65000, requiredIds = {49998}},								-- Death Strike (rank 2)
			},
	[64] =	{
				{id = 49927, cost =  64000, requiredIds = {49926}},								-- Blood Strike (rank 3)
				{id = 45529, cost =  64000},													-- Blood Tap
				{id = 55259, cost =   3200, requiredIds = {55258}, requiredTalentId = 55050},	-- Heart Strike (rank 3)
			},
	[65] =	{
				{id = 56222, cost =  65000},													-- Dark Command
				{id = 51417, cost =   3250, requiredIds = {51416}, requiredTalentId = 49143},	-- Frost Strike (rank 3)
				{id = 57330, cost =  65000},													-- Horn of Winter (rank 1)
				{id = 49918, cost =  65000, requiredIds = {49917}},								-- Plague Strike (rank 3)
			},
	[66] =	{
				{id = 49939, cost =  66000, requiredIds = {48721}},								-- Blood Boil (rank 2)
				{id = 48743, cost =  66000},													-- Death Pact
			},
	[67] =	{
				{id = 49936, cost =  68000, requiredIds = {43265}},								-- Death and Decay (rank 2)
				{id = 49903, cost =  67000, requiredIds = {49896}},								-- Icy Touch (rank 3)
				{id = 51423, cost =  67000, requiredIds = {49020}},								-- Obliterate (rank 2)
				{id = 56815, cost =  67000},													-- Rune Strike
				{id = 55265, cost =  18000, requiredIds = {55090}, requiredTalentId = 55090},	-- Scourge Strike (rank 2)
			},
	[68] =	{
				{id = 48707, cost =  68000},													-- Anti-Magic Shell
				{id = 49893, cost =  68000, requiredIds = {49892}},								-- Death Coil (rank 3)
			},
	[69] =	{
				{id = 49928, cost =  69000, requiredIds = {49927}},								-- Blood Strike (rank 4)
				{id = 55260, cost =   3450, requiredIds = {55259}, requiredTalentId = 55050},	-- Heart Strike (rank 4)
			},
	[70] =	{
				{id = 51326, cost =  18000, requiredIds = {51325}},								-- Corpse Explosion (rank 3)
				{id = 45463, cost =  63000, requiredIds = {49999}},								-- Death Strike (rank 3)
				{id = 51418, cost =  18000, requiredIds = {51417}, requiredTalentId = 49143},	-- Frost Strike (rank 4)
				{id = 51409, cost =   6500, requiredIds = {49184}, requiredTalentId = 49184},	-- Howling Blast (rank 2)
				{id = 49919, cost = 360000, requiredIds = {49918}},								-- Plague Strike (rank 4)
				{id = 48265, cost = 360000},													-- Unholy Presence
			},
	[72] =	{
				{id = 49940, cost = 360000, requiredIds = {49939}},								-- Blood Boil (rank 3)
				{id = 61999, cost = 360000},													-- Raise Ally
			},
	[73] =	{
				{id = 49937, cost = 360000, requiredIds = {49936}},								-- Death and Decay (rank 3)
				{id = 49904, cost = 360000, requiredIds = {49903}},								-- Icy Touch (rank 4)
				{id = 51424, cost = 360000, requiredIds = {51423}},								-- Obliterate (rank 3)
				{id = 55270, cost =  18000, requiredIds = {55265}, requiredTalentId = 55090},	-- Scourge Strike (rank 3)
			},
	[74] =	{
				{id = 49929, cost = 360000, requiredIds = {49928}},								-- Blood Strike (rank 5)
				{id = 55261, cost =  18000, requiredIds = {55260}, requiredTalentId = 55050},	-- Heart Strike (rank 5)
			},
	[75] =	{
				{id = 51327, cost =  18000, requiredIds = {51326}},								-- Corpse Explosion (rank 4)
				{id = 49923, cost = 360000, requiredIds = {45463}},								-- Death Strike (rank 4)
				{id = 47568, cost = 360000},													-- Empower Rune Weapon
				{id = 51419, cost =  18000, requiredIds = {51418}, requiredTalentId = 49143},	-- Frost Strike (rank 5)
				{id = 57623, cost = 360000, requiredIds = {57330}},								-- Horn of Winter (rank 2)
				{id = 51410, cost =  10000, requiredIds = {51409}, requiredTalentId = 49184},	-- Howling Blast (rank 3)
				{id = 49920, cost = 360000, requiredIds = {49919}},								-- Plague Strike (rank 5)
			},
	[76] =	{
				{id = 49894, cost = 360000, requiredIds = {49893}},								-- Death Coil (rank 4)
			},
	[78] =	{
				{id = 49941, cost = 360000, requiredIds = {49940}},								-- Blood Boil (rank 4)
				{id = 49909, cost = 360000, requiredIds = {49904}},								-- Icy Touch (arnk 5)
			},
	[79] =	{
				{id = 51425, cost = 360000, requiredIds = {51424}},								-- Obliterate (rank 4)
				{id = 55271, cost =  18000, requiredIds = {55270}, requiredTalentId = 55090},	-- Scourge Strike (rank 4)
			},
	[80] =	{
				{id = 42650, cost = 360000},													-- Army of the Dead
				{id = 49930, cost = 360000, requiredIds = {49929}},								-- Blood Strike (rank 6)
				{id = 51328, cost =  18000, requiredIds = {51327}},								-- Corpse Explosion (rank 5)
				{id = 49938, cost = 360000, requiredIds = {49937}},								-- Death and Decay (rank 4)
				{id = 49895, cost = 360000, requiredIds = {49894}},								-- Death Coil (rank 5)
				{id = 49924, cost = 360000, requiredIds = {49923}},								-- Death Strike (rank 5)
				{id = 55268, cost =  18000, requiredIds = {51419}, requiredTalentId = 49143},	-- Frost Strike (rank 6)
				{id = 55262, cost =  18000, requiredIds = {55261}, requiredTalentId = 55050},	-- Heart Strike (rank 6)
				{id = 51411, cost =  10000, requiredIds = {51410}, requiredTalentId = 49184},	-- Howling Blast (rank 4)
				{id = 49921, cost = 360000, requiredIds = {49920}}								-- Plague Strike (rank 6)
			},
}