--[[	file meta info
	@file 		Shaman.lua
	@brief		Tables of spell IDs for class
--]]

--[[
	@brief		Accessing the addons private table

	@var 	_		addonName, thrown away
	@var	wt		Global addonTable
--]]
local _, wt = ...

--[[
	@brief		Check if the data should be loaded or not
	@return		If not "SHAMAN", then return with nothing
--]]
if (wt.currentClass ~= "SHAMAN") then
	return
end


--[[
	@brief		Table for trainable spells for each level

	@table		[n]		Table containing spells available at level n

				@var		id					Spell id
				@var		cost				Cost in copper
				@table		requiredIds			Table containing prerequisite spell IDs
				@var		requiredTalentId	Spell ID of prerequisite talent
				@var		faction				"Alliance" or "Horde" for faction specific spells
--]]
wt.SpellsByLevel = wt.FactionFilter({
	[1] =	{
				{id =  8017, cost =     10},													-- Rockbiter Weapon (rank 1)
			},
	[4] =	{
				{id =  8042, cost =    100},													-- Earth Shock (rank 1)
			},
	[6] =	{
				{id =  2484, cost =    100},													-- Earthbind Totem
				{id =   332, cost =    100, requiredIds = {331}},								-- Healing Wave (rank 2)
			},
	[8] =	{
				{id =  8044, cost =    100, requiredIds = {8042}},								-- Earth Shock (rank 2)
				{id =   529, cost =    100, requiredIds = {403}},								-- Lightning Bolt (rank 2)
				{id =   324, cost =    100},													-- Lightning Shield (rank 1)
				{id =  8018, cost =    100, requiredIds = {8017}},								-- Rockbiter Weapon (rank 2)
				{id =  5730, cost =    100},													-- Stoneclaw Totem (rank 1)
			},
	[10] =	{
				{id =  8050, cost =    400},													-- Flame Shock (rank 1)
				{id =  8024, cost =    400},													-- Flametongue Weapon (rank 1)
				{id =  8075, cost =    400},													-- Strength of Earth Totem (rank 1)
			},
	[12] =	{
				{id =  2008, cost =    800},													-- Ancestral Spirit (rank 1)
				{id =  1535, cost =    800},													-- Fire Nova (rank 1)
				{id =   547, cost =    800, requiredIds = {332}},								-- Healing Wave (rank 3)
				{id =   370, cost =    800},													-- Purge (rank 1)
			},
	[14] =	{
				{id =  8045, cost =    900, requiredIds = {8044}},								-- Earth Shock (rank 3)
				{id =   548, cost =    900, requiredIds = {529}},								-- Lightning Bolt (rank 3)
				{id =  8154, cost =    900, requiredIds = {8071}},								-- Stoneskin Totem (rank 2)
			},
	[16] =	{
				{id =   526, cost =   1800},													-- Cure Toxins
				{id =  2645, cost =   2200},													-- Ghost Wolf
				{id =   325, cost =   1800, requiredIds = {324}},								-- Lightning Shield (rank 2)
				{id =  8019, cost =   1800, requiredIds = {8018}},								-- Rockbiter Weapon (rank 3)
				{id = 57994, cost =   2500},													-- Wind Shear
			},
	[18] =	{
				{id =  8052, cost =   2000, requiredIds = {8050}},								-- Flame Shock (rank 2)
				{id =  8027, cost =   2000, requiredIds = {8024}},								-- Flametongue Weapon (rank 2)
				{id =   913, cost =   2000, requiredIds = {547}},								-- Healing Wave (rank 4)
				{id =  6390, cost =   2000, requiredIds = {5730}},								-- Stoneclaw Totem (rank 2)
				{id =  8143, cost =   2000},													-- Tremor Totem
			},
	[20] =	{
				{id =  8056, cost =   2200},													-- Frost Shock (rank 1)
				{id =  8033, cost =   2200},													-- Frostbrand Weapon (rank 1)
				{id =  8004, cost =   2200},													-- Lesser Healing Wave (rank 1)
				{id =   915, cost =   2200, requiredIds = {548}},								-- Lightning Bolt (rank 4)
				{id =  6363, cost =   2200, requiredIds = {3599}},								-- Searing Totem (rank 2)
				{id = 52127, cost =   2200},													-- Water Shield (rank 1)
			},
	[22] =	{
				{id =  8498, cost =   3000, requiredIds = {1535}},								-- Fire Nova (rank 2)
				{id =   131, cost =   3000},													-- Water Breathing
			},
	[24] =	{
				{id = 20609, cost =   3500, requiredIds = {2008}},								-- Ancestral Spirit (rank 2)
				{id =  8046, cost =   3500, requiredIds = {8045}},								-- Earth Shock (rank 4)
				{id =  8181, cost =   3500},													-- Frost Resistance Totem (rank 1)
				{id =   939, cost =   3500, requiredIds = {913}},								-- Healing Wave (rank 5)
				{id =   905, cost =   3500, requiredIds = {325}},								-- Lightning Shield (rank 3)
				{id = 10399, cost =   3500, requiredIds = {8019}},								-- Rockbiter Weapon (rank 4)
				{id =  8155, cost =   3500, requiredIds = {8154}},								-- Stoneskin Totem (rank 3)
				{id =  8160, cost =   3500, requiredIds = {8075}},								-- Strength of Earth Totem (rank 2)
			},
	[26] =	{
				{id =  6196, cost =   4000},													-- Far Sight
				{id =  8030, cost =   4000, requiredIds = {8027}},								-- Flametongue Weapon (rank 3)
				{id =   943, cost =   4000, requiredIds = {915}},								-- Lightning Bolt (rank 5)
				{id =  8190, cost =   4000},													-- Magma Totem (rank 1)
				{id =  5675, cost =   4000},													-- Mana Spring Totem (rank 1)
			},
	[28] =	{
				{id =  8184, cost =   6000},													-- Fire Resistance Totem (rank 1)
				{id =  8053, cost =   6000, requiredIds = {8052}},								-- Flame Shock (rank 3)
				{id =  8227, cost =   6000},													-- Flametongue Totem (rank 1)
				{id =  8038, cost =   6000, requiredIds = {8033}},								-- Frostbrand Weapon (rank 2)
				{id =  8008, cost =   6000, requiredIds = {8004}},								-- Lesser Healing Wave (rank 2)
				{id =  6391, cost =   6000, requiredIds = {6390}},								-- Stoneclaw Totem (rank 3)
				{id = 52129, cost =   6000, requiredIds = {52127}},								-- Water Shield (rank 2)
				{id =   546, cost =   6000},													-- Water Walking
			},
	[30] =	{
				{id =   556, cost =   7000},													-- Astral Recall
				{id = 66842, cost =    700},													-- Call of the Elements
				{id = 51730, cost =   7000},													-- Earthliving Weapon (rank 1)
				{id =  8177, cost =   7000},													-- Grounding Totem
				{id =  6375, cost =   7000, requiredIds = {5394}},								-- Healing Stream Totem (rank 2)
				{id = 10595, cost =   7000},													-- Nature Resistance Totem (rank 1)
				{id = 20608, cost =   7000},													-- Reincarnation
				{id =  6364, cost =   7000, requiredIds = {6363}},								-- Searing Totem (rank 3)
				{id = 36936, cost =   7000},													-- Totemic Recall
				{id =  8232, cost =   7000},													-- Windfury Weapon (rank 1)
			},
	[32] =	{
				{id =   421, cost =   8000},													-- Chain Lightning (rank 1)
				{id =  8499, cost =   8000, requiredIds = {8498}},								-- Fire Nova (rank 3)
				{id =   959, cost =   8000, requiredIds = {939}},								-- Healing Wave (rank 6)
				{id =  6041, cost =   8000, requiredIds = {943}},								-- Lightning Bolt (rank 6)
				{id =   945, cost =   8000, requiredIds = {905}},								-- Lightning Shield (rank 4)
				{id =  8012, cost =   8000, requiredIds = {370}},								-- Purge (rank 2)
				{id =  8512, cost =   8000},													-- Windfury Totem
			},
	[34] =	{
				{id =  8058, cost =   9000, requiredIds = {8056}},								-- Frost Shock (rank 2)
				{id =  6495, cost =   9000},													-- Sentry Totem
				{id = 10406, cost =   9000, requiredIds = {8155}},								-- Stoneskin Totem (rank 4)
				{id = 52131, cost =   9000, requiredIds = {52129}},								-- Water Shield (rank 3)
			},
	[36] =	{
				{id = 20610, cost =  10000, requiredIds = {20609}},								-- Ancestral Spirit (rank 3)
				{id = 10412, cost =  10000, requiredIds = {8046}},								-- Earth Shock (rank 5)
				{id = 16339, cost =  10000, requiredIds = {8030}},								-- Flametongue Weapon (rank 4)
				{id =  8010, cost =  10000, requiredIds = {8008}},								-- Lesser Healing Wave (rank 3)
				{id = 10585, cost =  10000, requiredIds = {8190}},								-- Magma Totem (rank 2)
				{id = 10495, cost =  10000, requiredIds = {5675}},								-- Mana Spring Totem (rank 2)
			},
	[38] =	{
				{id =  8170, cost =  11000},													-- Cleansing Totem
				{id =  8249, cost =  11000, requiredIds = {8227}},								-- Flametongue Totem (rank 2)
				{id = 10478, cost =  11000, requiredIds = {8181}},								-- Frost Resistance Totem (rank 2)
				{id = 10456, cost =  11000, requiredIds = {8038}},								-- Frostbrand Weapon (rank 3)
				{id = 10391, cost =  11000, requiredIds = {6041}},								-- Lightning Bolt (rank 7)
				{id =  6392, cost =  11000, requiredIds = {6391}},								-- Stoneclaw Totem (rank 4)
				{id =  8161, cost =  11000, requiredIds = {8160}},								-- Strength of Earth Totem (rank 3)
			},
	[40] =	{
				{id = 66843, cost =    700},													-- Call of the Ancestors
				{id =  1064, cost =  12000},													-- Chain Heal (rank 1)
				{id =   930, cost =  12000, requiredIds = {421}},								-- Chain Lightning (rank 2)
				{id = 51988, cost =  12000, requiredIds = {51730}},								-- Earthliving Weapon (rank 2)
				{id = 10447, cost =  12000, requiredIds = {8053}},								-- Flame Shock (rank 4)
				{id =  6377, cost =  12000, requiredIds = {6375}},								-- Healing Stream Totem (rank 3)
				{id =  8005, cost =  12000, requiredIds = {959}},								-- Healing Wave (rank 7)
				{id =  8134, cost =  12000, requiredIds = {945}},								-- Lightning Shield (rank 5)
				{id =  6365, cost =  12000, requiredIds = {6364}},								-- Searing Totem (rank 4)
				{id =  8235, cost =  12000, requiredIds = {8232}},								-- Windfury Weapon (rank 2)
			},
	[41] =	{
				{id = 52134, cost =  12000, requiredIds = {52131}},								-- Water Shield (rank 4)
			},
	[42] =	{
				{id = 11314, cost =  16000, requiredIds = {8499}},								-- Fire Nova (rank 4)
				{id = 10537, cost =  16000, requiredIds = {8184}},								-- Fire Resistance Totem (rank 2)
			},
	[44] =	{
				{id = 10466, cost =  18000, requiredIds = {8010}},								-- Lesser Healing Wave (rank 4)
				{id = 10392, cost =  18000, requiredIds = {10391}},								-- Lightning Bolt (rank 8)
				{id = 10600, cost =  18000, requiredIds = {10595}},								-- Nature Resistance Totem (rank 2)
				{id = 10407, cost =  18000, requiredIds = {10406}},								-- Stoneskin Totem (rank 5)
			},
	[46] =	{
				{id = 10622, cost =  20000, requiredIds = {1064}},								-- Chain Heal (rank 2)
				{id = 16341, cost =  20000, requiredIds = {16339}},								-- Flametongue Weapon (rank 5)
				{id = 10472, cost =  20000, requiredIds = {8058}},								-- Frost Shock (rank 3)
				{id = 10586, cost =  20000, requiredIds = {10585}},								-- Magma Totem (rank 3)
				{id = 10496, cost =  20000, requiredIds = {10495}},								-- Mana Spring Totem (rank 3)
			},
	[48] =	{
				{id = 20776, cost =  22000, requiredIds = {20610}},								-- Ancestral Spirit (rank 4)
				{id =  2860, cost =  22000, requiredIds = {930}},								-- Chain Lightning (rank 3)
				{id = 10413, cost =  22000, requiredIds = {10412}},								-- Earth Shock (rank 6)
				{id = 10526, cost =  22000, requiredIds = {8249}},								-- Flametongue Totem (rank 3)
				{id = 16355, cost =  22000, requiredIds = {10456}},								-- Frostbrand Weapon (rank 4)
				{id = 10395, cost =  22000, requiredIds = {8005}},								-- Healing Wave (rank 8)
				{id = 10431, cost =  22000, requiredIds = {8134}},								-- Lightning Shield (rank 6)
				{id = 10427, cost =  22000, requiredIds = {6392}},								-- Stoneclaw Totem (rank 5)
				{id = 52136, cost =  22000, requiredIds = {52134}},								-- Water Shield (rank 5)
			},
	[50] =	{
				{id = 66844, cost =    700},													-- Call of the Spirits
				{id = 51991, cost =  24000, requiredIds = {51988}},								-- Earthliving Weapon (rank 3)
				{id = 10462, cost =  24000, requiredIds = {6377}},								-- Healing Stream Totem (rank 4)
				{id = 15207, cost =  24000, requiredIds = {10392}},								-- Lightning Bolt (rank 9)
				{id = 10437, cost =  24000, requiredIds = {6365}},								-- Searing Totem (rank 5)
				{id = 10486, cost =  24000, requiredIds = {8235}},								-- Windfury Weapon (rank 3)
			},
	[52] =	{
				{id = 11315, cost =  27000, requiredIds = {11314}},								-- Fire Nova (rank 5)
				{id = 10448, cost =  27000, requiredIds = {10447}},								-- Flame Shock (rank 5)
				{id = 10467, cost =  27000, requiredIds = {10466}},								-- Lesser Healing Wave (rank 5)
				{id = 10442, cost =  27000, requiredIds = {8161}},								-- Strength of Earth Totem (rank 4)
			},
	[54] =	{
				{id = 10623, cost =  29000, requiredIds = {10622}},								-- Chain Heal (rank 3)
				{id = 10479, cost =  29000, requiredIds = {10478}},								-- Frost Resistance Totem (rank 3)
				{id = 10408, cost =  29000, requiredIds = {10407}},								-- Stoneskin Totem (rank 6)
			},
	[55] =	{
				{id = 52138, cost =  29000, requiredIds = {52136}},								-- Water Shield (rank 6)
			},
	[56] =	{
				{id = 10605, cost =  30000, requiredIds = {2860}},								-- Chain Lightning (rank 4)
				{id = 16342, cost =  30000, requiredIds = {16341}},								-- Flametongue Weapon (rank 6)
				{id = 10396, cost =  30000, requiredIds = {10395}},								-- Healing Wave (rank 9)
				{id = 15208, cost =  30000, requiredIds = {15207}},								-- Lightning Bolt (rank 10)
				{id = 10432, cost =  30000, requiredIds = {10431}},								-- Lightning Shield (rank 7)
				{id = 10587, cost =  30000, requiredIds = {10586}},								-- Magma Totem (rank 4)
				{id = 10497, cost =  30000, requiredIds = {10496}},								-- Mana Spring Totem (rank 4)
			},
	[58] =	{
				{id = 10538, cost =  32000, requiredIds = {10537}},								-- Fire Resistance Totem (rank 3)
				{id = 16387, cost =  32000, requiredIds = {10526}},								-- Flametongue Totem (rank 4)
				{id = 10473, cost =  32000, requiredIds = {10472}},								-- Frost Shock (rank 4)
				{id = 16356, cost =  32000, requiredIds = {16355}},								-- Frostbrand Weapon (rank 5)
				{id = 10428, cost =  32000, requiredIds = {10427}},								-- Stoneclaw Totem (rank 6)
			},
	[60] =	{
				{id = 20777, cost =  34000, requiredIds = {20776}},								-- Ancestral Spirit (rank 5)
				{id = 32593, cost =   1700, requiredIds = {974}, requiredTalentId = 974},		-- Earth Shield (rank 2)
				{id = 10414, cost =  34000, requiredIds = {10413}},								-- Earth Shock (rank 7)
				{id = 51992, cost =  34000, requiredIds = {51991}},								-- Earthliving Weapon (rank 4)
				{id = 29228, cost =  65000, requiredIds = {10448}},								-- Flame Shock (rank 6)
				{id = 10463, cost =  34000, requiredIds = {10462}},								-- Healing Stream Totem (rank 5)
				{id = 25357, cost =   6500, requiredIds = {10396}},								-- Healing Wave (rank 10)
				{id = 10468, cost =  34000, requiredIds = {10467}},								-- Lesser Healing Wave (rank 6)
				{id = 10601, cost =  34000, requiredIds = {10600}},								-- Nature Resistance Totem (rank 3)
				{id = 10438, cost =  34000, requiredIds = {10437}},								-- Searing Totem (rank 6)
				{id = 25361, cost =  34000, requiredIds = {10442}},								-- Strength of Earth Totem (rank 5)
				{id = 57720, cost =   3400, requiredIds = {30706}, requiredTalentId = 30706},	-- Totem of Wrath (rank 2)
				{id = 16362, cost =  34000, requiredIds = {10486}},								-- Windfury Weapon (rank 4)
			},
	[61] =	{
				{id = 25422, cost =  34000, requiredIds = {10623}},								-- Chain Heal (rank 4)
				{id = 25546, cost =  34000, requiredIds = {11315}},								-- Fire Nova (rank 6)
			},
	[62] =	{
				{id = 25448, cost =  38000, requiredIds = {15208}},								-- Lightning Bolt (rank 11)
				{id = 24398, cost =  38000, requiredIds = {52138}},								-- Water Shield (rank 7)
			},
	[63] =	{
				{id = 25439, cost =  42000, requiredIds = {10605}},								-- Chain Lightning (rank 5)
				{id = 25391, cost =  42000, requiredIds = {25357}},								-- Healing Wave (rank 11)
				{id = 25469, cost =  42000, requiredIds = {10432}},								-- Lightning Shield (rank 8)
				{id = 25508, cost =  42000, requiredIds = {10408}},								-- Stoneskin Totem (rank 7)
			},
	[64] =	{
				{id = 25489, cost =  47000, requiredIds = {16342}},								-- Flametongue Weapon (rank 7)
				{id =  3738, cost =  47000},													-- Wrath of Air Totem
			},
	[65] =	{
				{id = 25552, cost =  52000, requiredIds = {10587}},								-- Magma Totem (rank 5)
				{id = 25570, cost =  52000, requiredIds = {10497}},								-- Mana Spring Totem (rank 5)
				{id = 25528, cost =  52000, requiredIds = {25361}},								-- Strength of Earth Totem (rank 6)
			},
	[66] =	{
				{id =  2062, cost =  58000},													-- Earth Elemental Totem
				{id = 25500, cost =  58000, requiredIds = {16356}},								-- Frostbrand Weapon (rank 6)
				{id = 25420, cost =  58000, requiredIds = {10468}},								-- Lesser Healing Wave (rank 7)
			},
	[67] =	{
				{id = 25557, cost =  64000, requiredIds = {16387}},								-- Flametongue Totem (rank 5)
				{id = 25560, cost =  64000, requiredIds = {10479}},								-- Frost Resistance Totem (rank 4)
				{id = 25449, cost =  64000, requiredIds = {25448}},								-- Lightning Bolt (rank 12)
				{id = 25525, cost =  64000, requiredIds = {10428}},								-- Stoneclaw Totem (rank 7)
			},
	[68] =	{
				{id = 25423, cost =  71000, requiredIds = {25422}},								-- Chain Heal (rank 5)
				{id =  2894, cost =  71000},													-- Fire Elemental Totem
				{id = 25563, cost =  71000, requiredIds = {10538}},								-- Fire Resistance Totem (rank 4)
				{id = 25464, cost =  71000, requiredIds = {10473}},								-- Frost Shock (rank 5)
				{id = 25505, cost =  71000, requiredIds = {16362}},								-- Windfury Weapon (rank 5)
			},
	[69] =	{
				{id = 25590, cost =  79000, requiredIds = {20777}},								-- Ancestral Spirit (rank 6)
				{id = 25454, cost =  79000, requiredIds = {10414}},								-- Earth Shock (rank 8)
				{id = 25567, cost =  79000, requiredIds = {10463}},								-- Healing Stream Totem (rank 6)
				{id = 25574, cost =  79000, requiredIds = {10601}},								-- Nature Resistance Totem (rank 4)
				{id = 25533, cost =  79000, requiredIds = {10438}},								-- Searing Totem (rank 7)
				{id = 33736, cost =  79000, requiredIds = {24398}},								-- Water Shield (rank 8)
			},
	[70] =	{
				{id =  2825, cost =  88000, faction = "Horde"},									-- Bloodlust
				{id = 25442, cost =  88000, requiredIds = {25439}},								-- Chain Lightning (rank 6)
				{id = 32594, cost =   5000, requiredIds = {32593}, requiredTalentId = 974},		-- Earth Shield (rank 2)
				{id = 51993, cost =  71000, requiredIds = {51992}},								-- Earthliving Weapon (rank 5)
				{id = 25547, cost =  88000, requiredIds = {25546}},								-- Fire Nova (rank 7)
				{id = 25457, cost =  88000, requiredIds = {29228}},								-- Flame Shock (rank 7)
				{id = 25396, cost =  88000, requiredIds = {25391}},								-- Healing Wave (rank 12)
				{id = 32182, cost =  88000, faction = "Alliance"},								-- Heroism
				{id = 25472, cost =  88000, requiredIds = {25469}},								-- Lightning Shield (rank 9)
				{id = 61299, cost =   9000, requiredIds = {61295}, requiredTalentId = 61295},	-- Riptide (rank 2)
				{id = 25509, cost =  88000, requiredIds = {25508}},								-- Stoneskin Totem (rank 8)
				{id = 59156, cost =  88000, requiredIds = {51490}, requiredTalentId = 51490},	-- Thunderstorm (rank 2)
				{id = 57721, cost =   5200, requiredIds = {57720}, requiredTalentId = 30706},	-- Totem of Wrath (rank 3)
			},
	[71] =	{
				{id = 58649, cost = 180000, requiredIds = {25557}},								-- Flametongue Totem (rank 6)
				{id = 58785, cost = 180000, requiredIds = {25489}},								-- Flametongue Weapon (rank 8)
				{id = 58794, cost = 180000, requiredIds = {25500}},								-- Frostbrand Weapon (rank 7)
				{id = 58755, cost = 180000, requiredIds = {25567}},								-- Healing Stream Totem (rank 7)
				{id = 58771, cost = 180000, requiredIds = {25570}},								-- Mana Spring Totem (rank 6)
				{id = 58699, cost = 180000, requiredIds = {25533}},								-- Searing Totem (rank 8)
				{id = 58580, cost = 180000, requiredIds = {25525}},								-- Stoneclaw Totem (rank 8)
				{id = 58801, cost = 180000, requiredIds = {25505}},								-- Windfury Weapon (rank 6)
			},
	[72] =	{
				{id = 49275, cost = 180000, requiredIds = {25420}},								-- Lesser Healing Wave (rank 8)
			},
	[73] =	{
				{id = 49235, cost = 180000, requiredIds = {25464}},								-- Frost Shock (rank 6)
				{id = 49237, cost = 180000, requiredIds = {25449}},								-- Lightning Bolt (rank 13)
				{id = 58731, cost = 180000, requiredIds = {25552}},								-- Magma Totem (rank 6)
				{id = 58751, cost = 180000, requiredIds = {25509}},								-- Stoneskin Totem (rank 9)
			},
	[74] =	{
				{id = 55458, cost = 180000, requiredIds = {25423}},								-- Chain Heal (rank 6)
				{id = 49270, cost = 180000, requiredIds = {25442}},								-- Chain Lightning (rank 7)
				{id = 49230, cost = 180000, requiredIds = {25454}},								-- Earth Shock (rank 9)
			},
	[75] =	{
				{id = 49283, cost =   9000, requiredIds = {32594}, requiredTalentId = 974},		-- Earth Shield (rank 3)
				{id = 61649, cost = 180000, requiredIds = {25547}},								-- Fire Nova (rank 8)
				{id = 58737, cost = 180000, requiredIds = {25563}},								-- Fire Resistance Totem (rank 5)
				{id = 49232, cost = 180000, requiredIds = {25457}},								-- Flame Shock (rank 8)
				{id = 58652, cost = 180000, requiredIds = {58649}},								-- Flametongue Totem (rank 7)
				{id = 58741, cost = 180000, requiredIds = {25560}},								-- Frost Resistance Totem (rank 5)
				{id = 49272, cost = 180000, requiredIds = {25396}},								-- Healing Wave (rank 13)
				{id = 51505, cost = 180000},													-- Lava Burst (rank 1)
				{id = 49280, cost = 180000, requiredIds = {25472}},								-- Lightning Shield (rank 10)
				{id = 58746, cost = 180000, requiredIds = {25574}},								-- Nature Resistance Totem (rank 5)
				{id = 61300, cost =   9000, requiredIds = {61299}, requiredTalentId = 61295},	-- Riptide (rank 3)
				{id = 58703, cost = 180000, requiredIds = {58699}},								-- Searing Totem (rank 9)
				{id = 58581, cost = 180000, requiredIds = {58580}},								-- Stoneclaw Totem (rank 9)
				{id = 57622, cost = 180000, requiredIds = {25528}},								-- Strength of Earth Totem (rank 7)
				{id = 59158, cost = 180000, requiredIds = {59156}, requiredTalentId = 51490},	-- Thunderstorm (rank 3)
			},
	[76] =	{
				{id = 58789, cost = 180000, requiredIds = {58785}},								-- Flametongue Weapon (rank 9)
				{id = 58795, cost = 180000, requiredIds = {58794}},								-- Frostbrand Weapon (rank 8)
				{id = 58756, cost = 180000, requiredIds = {58755}},								-- Healing Stream Totem (rank 8)
				{id = 58773, cost = 180000, requiredIds = {58771}},								-- Mana Spring Totem (rank 7)
				{id = 57960, cost = 180000, requiredIds = {33736}},								-- Water Shield (rank 9)
				{id = 58803, cost = 180000, requiredIds = {58801}},								-- Windfury Weapon (rank 7)
			},
	[77] =	{
				{id = 49276, cost = 180000, requiredIds = {49275}},								-- Lesser Healing Wave (rank 9)
			},
	[78] =	{
				{id = 49236, cost = 180000, requiredIds = {49235}},								-- Frost Shock (rank 7)
				{id = 58734, cost = 180000, requiredIds = {58731}},								-- Magma Totem (rank 7)
				{id = 58582, cost = 180000, requiredIds = {58581}},								-- Stoneclaw Totem (rank 10)
				{id = 58753, cost = 180000, requiredIds = {58751}},								-- Stoneskin Totem (rank 10)
			},
	[79] =	{
				{id = 49231, cost = 180000, requiredIds = {49230}},								-- Earth Shock (rank 10)
				{id = 49238, cost = 180000, requiredIds = {49237}},								-- Lightning Bolt (rank 14)
			},
	[80] =	{
				{id = 49277, cost = 180000, requiredIds = {25590}},								-- Ancestral Spirit (rank 7)
				{id = 55459, cost = 180000, requiredIds = {55458}},								-- Chain Heal (rank 7)
				{id = 49271, cost = 180000, requiredIds = {49270}},								-- Chain Lightning (rank 8)
				{id = 49284, cost =   9000, requiredIds = {49283}, requiredTalentId = 974},		-- Earth Shield (rank 4)
				{id = 51994, cost = 180000, requiredIds = {51993}},								-- Earthliving Weapon (rank 6)
				{id = 61657, cost = 180000, requiredIds = {61649}},								-- Fire Nova (rank 9)
				{id = 58739, cost = 180000, requiredIds = {58737}},								-- Fire Resistance Totem (rank 6)
				{id = 49233, cost = 180000, requiredIds = {49232}},								-- Flame Shock (rank 9)
				{id = 58656, cost = 180000, requiredIds = {58652}},								-- Flametongue Totem (rank 8)
				{id = 58790, cost = 180000, requiredIds = {58789}},								-- Flametongue Weapon (rank 10)
				{id = 58745, cost = 180000, requiredIds = {58741}},								-- Frost Resistance Totem (rank 6)
				{id = 58796, cost = 180000, requiredIds = {58795}},								-- Frostbrand Weapon (rank 9)
				{id = 58757, cost = 180000, requiredIds = {58756}},								-- Healing Stream Totem (rank 9)
				{id = 49273, cost = 180000, requiredIds = {49272}},								-- Healing Wave (rank 14)
				{id = 51514, cost = 180000},													-- Hex
				{id = 60043, cost = 180000, requiredIds = {51505}},								-- Lava Burst (rank 2)
				{id = 49281, cost = 180000, requiredIds = {49280}},								-- Lightning Shield (rank 11)
				{id = 58774, cost = 180000, requiredIds = {58773}},								-- Mana Spring Totem (rank 8)
				{id = 58749, cost = 180000, requiredIds = {58746}},								-- Nature Resistance Totem (rank 6)
				{id = 61301, cost =   9000, requiredIds = {61300}, requiredTalentId = 61295},	-- Riptide (rank 4)
				{id = 58704, cost = 180000, requiredIds = {58703}},								-- Searing Totem (rank 10)
				{id = 58643, cost = 180000, requiredIds = {57622}},								-- Strength of Earth Totem (rank 8)
				{id = 59159, cost = 180000, requiredIds = {59158}, requiredTalentId = 51490},	-- Thunderstorm (rank 3)
				{id = 57722, cost =  10000, requiredIds = {57721}, requiredTalentId = 30706},	-- Totem of Wrath (rank 4)
				{id = 58804, cost = 180000, requiredIds = {58803}},								-- Windfury Weapon (rank 8)
			},
})
